@@ -23,11 +23,6 @@ LOGS_FILE_NAME = 'LOGS_FILE_NAME'
 ENABLE_LOGS_WITH_COLORS = 'ENABLE_LOGS_WITH_COLORS'
 LOGS_WITH_COLORS = 'ENABLE_LOGS_WITH_COLORS'
 
-LEVEL_NOT_ACTIVE_BY_DEFAULT_LIST = [
-    LOG,
-    DEBUG,
-    WRAPPER
-]
 
 global LOG_HELPER_SETTINGS
 
@@ -40,7 +35,7 @@ def logIt(it, **kwargs):
     #     print(it, **kwargs)
     print(it, **kwargs)
 
-def loadSettings(logsFileName=None, withColors=False, disabledByDefault=LEVEL_NOT_ACTIVE_BY_DEFAULT_LIST) :
+def loadSettings(logsFileName=None, withColors=False) :
     global LOG_HELPER_SETTINGS
     colorama.deinit()
     activeEnvironment = SettingHelper.getActiveEnvironment()
@@ -52,7 +47,7 @@ def loadSettings(logsFileName=None, withColors=False, disabledByDefault=LEVEL_NO
             LOGS_WITH_COLORS: colorsAreEnabled
         },
         **{
-            level: (c.TRUE if level not in disabledByDefault and EnvironmentHelper.isTrue(level, default=True) else c.FALSE) for level in LogHelperHelper.LEVEL_DICTIONARY
+            level: (c.TRUE if EnvironmentHelper.isTrue(level, default=True) else c.FALSE) for level in LogHelperHelper.LEVEL_DICTIONARY
         }
     }
     if colorsAreEnabled:
